@@ -18,18 +18,15 @@ SEXP
     lme4_ZtZSym,
     lme4_ZtySym,
     lme4_bVarSym,
-    lme4_callSym,
     lme4_cnamesSym,
     lme4_devCompSym,
     lme4_devianceSym,
     lme4_diagSym,
     lme4_factorSym,
-    lme4_familySym,
     lme4_fixefSym,
     lme4_flistSym,
     lme4_gradCompSym,
     lme4_iSym,
-    lme4_methodSym,
     lme4_ncSym,
     lme4_pSym,
     lme4_permSym,
@@ -38,7 +35,6 @@ SEXP
     lme4_ranefSym,
     lme4_statusSym,
     lme4_uploSym,
-    lme4_useScaleSym,
     lme4_wrkresSym,
     lme4_wtsSym,
     lme4_xSym,
